@@ -2,20 +2,21 @@ import logging
 from datetime import datetime
 
 from .const import FanModes, ActivityNames
+from .util import safely_get_json_value
 
 _LOGGER = logging.getLogger(__name__)
 
 
 def active_schedule_periods(periods_json: [dict]):
-    return list(filter(lambda period: period["enabled"] == "on", periods_json))
+    return list(filter(lambda period: safely_get_json_value(period, "enabled") == "on", periods_json))
 
 
 class ConfigZoneActivity:
     def __init__(self, zone_activity_json: dict):
-        self.api_id: ActivityNames = ActivityNames(zone_activity_json["$"]["id"])
+        self.api_id: ActivityNames = ActivityNames(safely_get_json_value(zone_activity_json, "$.id"))
         self.fan: FanModes = FanModes(zone_activity_json["fan"])
-        self.heat_set_point: float = float(zone_activity_json["htsp"])
-        self.cool_set_point: float = float(zone_activity_json["clsp"])
+        self.heat_set_point: float = safely_get_json_value(zone_activity_json, "htsp", float)
+        self.cool_set_point: float = safely_get_json_value(zone_activity_json, "clsp", float)
 
     def __repr__(self):
         return {
@@ -26,22 +27,19 @@ class ConfigZoneActivity:
         }
 
     def __str__(self):
-        return f"{self.__repr__()}"
+        return str(self.__repr__())
 
 
 class ConfigZone:
     def __init__(self, zone_json: dict, vacation_json: dict):
-        self.api_id = zone_json["$"]["id"]
-        self.name: str = zone_json["name"]
-        raw_hold_activity_name = zone_json.get("holdActivity", None)
-        self.hold_activity: ActivityNames = None
-        if raw_hold_activity_name is not None:
-            self.hold_activity: ActivityNames = ActivityNames(raw_hold_activity_name)
-        self.hold: bool = zone_json["hold"] == "on"
-        self.hold_until: str = zone_json.get("otmr", None)
-        self.program_json: dict = zone_json["program"]
+        self.api_id = safely_get_json_value(zone_json, "$.id")
+        self.name: str = safely_get_json_value(zone_json, "name")
+        self.hold_activity: ActivityNames = safely_get_json_value(zone_json, "holdActivity", ActivityNames)
+        self.hold: bool = safely_get_json_value(zone_json, "hold") == "on"
+        self.hold_until: str = safely_get_json_value(zone_json, "otmr")
+        self.program_json: dict = safely_get_json_value(zone_json, "program")
         self.activities = []
-        for zone_activity_json in zone_json["activities"]["activity"]:
+        for zone_activity_json in safely_get_json_value(zone_json, "activities.activity"):
             self.activities.append(
                 ConfigZoneActivity(zone_activity_json=zone_activity_json)
             )
@@ -67,12 +65,12 @@ class ConfigZone:
                 if (int(hours) < now.hour) or (
                     int(hours) == now.hour and int(minutes) < now.minute
                 ):
-                    return self.find_activity(ActivityNames(active_period["activity"]))
+                    return self.find_activity(safely_get_json_value(active_period, "activity", ActivityNames))
             yesterday_schedule = self.program_json["day"][sunday_0_index_today + 8 % 7]
             yesterday_active_periods = reversed(
                 active_schedule_periods(yesterday_schedule["period"])
             )
-            return self.find_activity(ActivityNames(yesterday_active_periods[-1]["activity"]))
+            return self.find_activity(safely_get_json_value(yesterday_active_periods[-1], "activity", ActivityNames))
 
     def next_activity_time(self) -> str:
         now = datetime.now()
@@ -102,11 +100,7 @@ class ConfigZone:
         return builder
 
     def __str__(self):
-        builder = self.__repr__()
-        builder["activities"] = ", ".join(
-            map(lambda activity: activity.__str__(), self.activities)
-        )
-        return str(builder)
+        return str(self.__repr__())
 
 
 class Config:
@@ -129,11 +123,11 @@ class Config:
         self.raw_config_json = self.system.api_connection.get_config(
             system_serial=self.system.serial
         )
-        self.temperature_unit = self.raw_config_json["cfgem"]
-        self.static_pressure = self.raw_config_json["staticPressure"]
-        self.mode = self.raw_config_json["mode"]
-        self.limit_min = int(self.raw_config_json["utilityEvent"]["minLimit"])
-        self.limit_max = int(self.raw_config_json["utilityEvent"]["maxLimit"])
+        self.temperature_unit = safely_get_json_value(self.raw_config_json, "cfgem")
+        self.static_pressure = safely_get_json_value(self.raw_config_json, "staticPressure")
+        self.mode = safely_get_json_value(self.raw_config_json, "mode")
+        self.limit_min = safely_get_json_value(self.raw_config_json, "utilityEvent.minLimit", int)
+        self.limit_max = safely_get_json_value(self.raw_config_json, "utilityEvent.maxLimit", int)
         vacation_json = {
             "$": {"id": "vacation"},
             "clsp": self.raw_config_json["vacmaxt"],
@@ -141,8 +135,8 @@ class Config:
             "fan": self.raw_config_json["vacfan"],
         }
         self.zones = []
-        for zone_json in self.raw_config_json["zones"]["zone"]:
-            if zone_json["enabled"] == "on":
+        for zone_json in safely_get_json_value(self.raw_config_json, "zones.zone"):
+            if safely_get_json_value(zone_json, "enabled") == "on":
                 self.zones.append(
                     ConfigZone(zone_json=zone_json, vacation_json=vacation_json)
                 )
@@ -158,6 +152,4 @@ class Config:
         }
 
     def __str__(self):
-        builder = self.__repr__()
-        builder["zones"] = ", ".join(map(lambda zone: zone.__str__(), self.zones))
-        return str(builder)
+        return str(self.__repr__())
